@@ -378,12 +378,16 @@ fr_command_zip_handle_error (FrCommand *comm,
 }
 
 
-const char *zip_mime_type[] = { "application/x-cbz",
-				"application/x-ear",
-				"application/x-ms-dos-executable",
-				"application/x-war",
-				"application/zip",
-				NULL };
+const char *zip_mime_type[] = {
+	"application/epub+zip",
+	"application/x-cbz",
+	"application/x-chrome-extension",
+	"application/x-ear",
+	"application/x-ms-dos-executable",
+	"application/x-war",
+	"application/zip",
+	NULL
+};
 
 
 static const char **
